<?php

namespace SupNext\Controllers\QuoteSheetGrid;

use SupNext\Util\Util;
use SupNext\Services\QuoteSheetGrid\GetHistoryTradingService as Service;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;

class GetHistoryTradingController {
    private $util;
    private $service;

    public function __construct(Util $util, Service $service) {
        $this->util    = $util;
        $this->service = $service;
    }

    public function getHistoryTrading(Request $request, Response $response) {
        $data = $request->getParameters();

        try {
            $itemColeTrading = $this->getItemColeTrading($data);
            $originalPrice    = [
                "VRPRECUNORIG" => $itemColeTrading["VRPRECUNORIG"],
                "VRPRECECORIG" => $itemColeTrading["VRPRECECORIG"],
                "VRPRECPIORIG" => $itemColeTrading["VRPRECPIORIG"]
            ];

            $latestQuoteSupplier = $this->getLatestQuoteSupplier($data);
            $lastPurchase = $this->getLastPurchase($data);

            $data["DTINIVALITM"] = $itemColeTrading["DTINIVALITM"];
            $data["DTFINVALITM"] = $itemColeTrading["DTFINVALITM"];
            $data["IDTIPOFORN"]  = "N";

            $minPriceNormalEco = $this->getLowestPriceEco($data);

            $data["IDTIPOFORN"] = "A";
            $minAlternativeEcoPrec = $this->getLowestPriceEco($data);
            $paymentDeadline = $this->getPaymentDeadlineItemCole($data);

            if (!empty($lastPurchase)) {
                $data["CDFILDEST"]   = $lastPurchase[0]["CDFILDEST"];
                $data["CDFILLANC"]   = $lastPurchase[0]["CDFILLANC"];
                $data["NRAUTOFORN"]  = $lastPurchase[0]["NRAUTOFORN"];
                $data["DTPROGENTAF"] = $lastPurchase[0]["DTPROGENTAF"];

                $procResult = $this->service->procPrecoEconAf($data);
            }

            $historyTrading = [
                "ULTCOTFORN" => !empty($latestQuoteSupplier) ? $latestQuoteSupplier[0] : null,
                "MINPRECNOR" => !empty($minPriceNormalEco) ? $minPriceNormalEco[0] : null,
                "MINPRECALT" => !empty($minAlternativeEcoPrec) ? $minAlternativeEcoPrec[0] : null,
                "PRAZPGTCOL" => !empty($paymentDeadline) ? $paymentDeadline[0] : null,
                "ULTCMP"     => !empty($lastPurchase) ? $lastPurchase[0] : $lastPurchase,
                "ITEMCOLE"   => $itemColeTrading,
                "PRECORI"    => $originalPrice,
                "PROC"       => $procResult ?? 0
            ];

            return $response->addDataSet(new DataSet("historyTrading", $historyTrading));
        } catch (\Exception $exception) {
            throw new \Exception("Erro ao pegar histórico negociação: " . $exception->getMessage(), 500);
        }
    }

    private function getItemColeTrading(array $data) {
        $conditions = [
            "CDREGIAO"    => $data["CDREGIAO"],
            "CDFILIAL"    => $data["CDFILIAL"],
            "NRCOLEPRECO" => $data["NRCOLEPRECO"],
            "CDPRODUTO"   => $data["CDPRODUTO"],
            "CDMARCA"     => $data["CDMARCA"],
            "CDFORNECED"  => $data["CDFORNECED"],
            "NRORG"       => $data["NRORG"]
        ];
        $itemColeTrading = $this->util->filteredDataSet($conditions, "getItemColeTrading")[0];

        return $itemColeTrading;
    }

    private function getLatestQuoteSupplier(array $data) {
        $conditions = [
            "CDFILIAL"    => $data["CDFILIAL"],
            "CDPRODUTO"   => $data["CDPRODUTO"],
            "CDFORNECED"  => $data["CDFORNECED"],
            "CDMARCA"     => $data["CDMARCA"],
            "NRORG"       => $data["NRORG"],
            "CDFILIAL"    => $data["CDFILIAL"],
            "NRCOLEPRECO" => $data["NRCOLEPRECO"],
            "CDPRODUTO"   => $data["CDPRODUTO"],
            "CDMARCA"     => $data["CDMARCA"]
        ];
        $latestQuoteSupplier = $this->util->filteredDataSet($conditions, "getLatestQuoteSupplier");

        return $latestQuoteSupplier;
    }

    private function getLastPurchase(array $data) {
        $conditions = [
            "CDPRODUTO" => $data["CDPRODUTO"],
            "CDMARCA"   => $data["CDMARCA"],
            "CDCENTCMP" => $data["CDFILIAL"],
            "CDPRODUTO" => $data["CDPRODUTO"],
            "CDMARCA"   => $data["CDMARCA"],
            "NRORG"     => $data["NRORG"],
            "CDPRODUTO" => $data["CDPRODUTO"],
            "CDMARCA"   => $data["CDMARCA"]
        ];
        $lastPurchase = $this->util->filteredDataSet($conditions, "getLastPurchase");

        return $lastPurchase;
    }

    private function getLowestPriceEco(array $data) {
        $conditions = [
            "CDFILIAL"    => $data["CDFILIAL"],
            "NRCOLEPRECO" => $data["NRCOLEPRECO"],
            "CDFILIAL"    => $data["CDFILIAL"],
            "CDPRODUTO"   => $data["CDPRODUTO"],
            "CDMARCA"     => $data["CDMARCA"],
            "CDREGIAO"    => $data["CDREGIAO"],
            "NRORG"       => $data["NRORG"],
            "CDFILIAL"    => $data["CDFILIAL"],
            "CDFILIAL"    => $data["CDFILIAL"],
            "CDPRODUTO"   => $data["CDPRODUTO"],
            "CDMARCA"     => $data["CDMARCA"],
            "CDREGIAO"    => $data["CDREGIAO"],
            "DTINIVALITM" => $data["DTINIVALITM"],
            "DTFINVALITM" => $data["DTFINVALITM"],
            "NRCOLEPRECO" => $data["NRCOLEPRECO"],
            "IDTIPOFORN"  => $data["IDTIPOFORN"]
        ];
        $lowestPriceEco = $this->util->filteredDataSet($conditions, "getLowestPriceEco");

        return $lowestPriceEco;
    }

    private function getPaymentDeadlineItemCole(array $data) {
        $conditions = [
            "CDFILIAL"    => $data["CDFILIAL"],
            "NRCOLEPRECO" => $data["NRCOLEPRECO"],
            "CDFORNECED"  => $data["CDFORNECED"],
            "CDPRODUTO"   => $data["CDPRODUTO"],
            "CDMARCA"     => $data["CDMARCA"],
            "CDREGIAO"    => $data["CDREGIAO"],
            "NRORG"       => $data["NRORG"]
        ];

        $paymentDeadline = $this->util->filteredDataSet($conditions, "getPaymentDeadlineItemCole");

        return $paymentDeadline;
    }
}
