<?php

namespace SupNext\Controllers\QuoteSheetGrid;

use SupNext\Services\QuoteSheetGrid\ReplicateQuotationService as Service;
use SupNext\Util\Util;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

class ReplicateQuotationController {
  private $service;
  private $util;

  public function __construct(Service $service, Util $util) {
    $this->service = $service;
    $this->util    = $util;
  }

  public function replicateQuotation(Request $request, Response $response) {
    $data = $request->getParameters();

    try{
      // if ($data["CONSCOTAN"] === "S") {
      //   $conditions = [
      //     "CDOPERADOR"    => $data["CDOPERADOR"],
      //     "TCDOPERADOR"   => $data["TCDOPERADOR"],
      //     "CDOPERADOR"    => $data["CDOPERADOR"],
      //     "CDOPERADOR"    => $data["CDOPERADOR"],
      //     "CDFILIAL"      => $data["CDFILIAL"],
      //     "NRORG"         => $data["NRORG"],
      //     "IDDUPLICA"     => $data["IDDUPLICA"],
      //     "DTINIVALCOL"   => $data["DTINIVALCOL"],
      //     "DTFINVALCOL"   => $data["DTFINVALCOL"],
      //     "IDDUPLICA"     => $data["IDDUPLICA"],
      //     "NRCOLEDUP"     => $data["NRCOLEPRECO"],
      //     "CDREGIAO"      => $data["CDREGIAO"],
      //     "NRORG"         => $data["NRORG"],
      //     "DTININOVA"     => $data["DTNOVINIVAL"],
      //     "DTFINNOVA"     => $data["DTNOVFINVAL"]
      //   ];

      //   $this->util->filteredDataSet($conditions, "getConsCotAn");
      // }

      $data["REAJUSTE"] = (float) $data["REAJUSTE"];
      $data["NRSEMAINIC"] = (string) $data["NRSEMAINIC"];
      $data["NRSEMAFINAL"] = (string) $data["NRSEMAFINAL"];
      $data = $this->util->implodeFields($data, ["CDREGIAO", "CDREGIAOOL"]);

      if(isset($data["DUPLICAOL"]) && $data["DUPLICAOL"] === "S") $this->checkOLRegion($data);

      $dupQuotation = $this->service->procReplicDuplicQuotation($data);

      return $response->addDataSet(new DataSet("replicateQuotation", ["message" => "Replicação da cotação realizada com sucesso.", $dupQuotation, "status_code" => 200]));
    } catch (\Exception $exception) {
      throw new \Exception("Erro ao replicar cotação: " . $exception->getMessage(), 500);
    }
  }

  private function checkOLRegion($data) {
    $OLSupplier = isset($data["CDFORNECED"]) ? ($data["CDFORNECED"]) : NULL;
    $conditions = [
      "P_CDFORNOPELOG" => $OLSupplier
    ];

    $OLRegion = $this->util->filteredDataSet($conditions, "OLRegionField");

    if (isset($OLRegion) && !count($OLRegion)) {
      return $response->setError(new Error("sup::NO_REGION_REGISTERED_FOR_LOGISTICS_OPERATOR", 400));
    }
  }
}