<?php

namespace SupNext\Controllers\QuoteSheetGrid;

use Teknisa\Libs\Util\Environment;
use SupNext\Util\Util;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

class ValidateOperatorController {
  private $environment;
  private $util;

  public function __construct(Environment $environment, Util $util) {
    $this->environment = $environment;
    $this->util        = $util;
  }

    public function validateOperator(Request $request, Response $response)
    {
        try {
            $data = $request->getParameters();
            $conditions = [
                "CDCOMPRADOR" => $data["CDOPERADOR"],
                "NRORG"       => $data["NRORG"],
            ];

            $operators = $this->util->filteredDataSet($conditions, "relateOperators");

            if ($data["CDOPERADOR"] != $this->environment->getCdoperador()) {
                if(!$this->operatorExist($operators)){
                    $response->setError(new Error("sup::OPERATOR_NOT_RELATED", 401));
                }
            }

            if ($data["IDUTINDICECOL"] == "S") {
                $conditions = [
                    "CDFILIAL"    => $data["CDFILIAL"],
                    "NRCOLEPRECO" => $data["NRCOLEPRECO"],
                    "NRORG"       => $data["NRORG"],
                ];

                $financialIndex = $this->util->filteredDataSet($conditions, "verifyFinancialIndex");

                if (count($financialIndex) > 0) {
                    $response->setError(new Error("sup::INDEX_MUST_BE_INFORMED", 400));
                }
            }

            return $response->addDataSet(new DataSet("validateOperator", ["message" => "OK", "status_code" => 200]));
        } catch (\Exception $exception) {
            throw new \Exception("Erro ao validar comprador: " . $exception->getMessage(), 500);
        }
    }

    private function operatorExist(array $operators) {
        $occurrences = 0;

        for ($i = 0; $i < count($operators); $i++) {
            if (in_array($this->environment->getCdoperador(), $operators[$i])) return $operators[$i];

            $occurrences += 1;
        }

        if ($occurrences == ((is_array($operators) && !is_null($operators)) ? count($operators) : 0)) {
            return false;
        }
    }
}
