<?php

namespace SupNext\Services\QuoteSheetGrid;

use Doctrine\DBAL\Connection;
use SupNext\Util\Util;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class AddSupplierService {
  private $connection;
  private $util;

  public function __construct(Connection $connection, Util $util) {
    $this->connection = $connection;
    $this->util       = $util;
  }

  public function procIncFornCota(array $data): array {
    try {
      $procedure = new StoredProcedure($this->connection, "INC_FORN_COTA");

      $procedure->addParam(new Param("P_CDFILIAL",    Param::PARAM_INPUT, $data["CDFILIAL"],      Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param("P_NRCOLEPRECO", Param::PARAM_INPUT, $data["NRCOLEPRECO"],   Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param("P_CDFORNECED",  Param::PARAM_INPUT, $data["CDFORNECED"],    Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param("P_CDOPERSIS",   Param::PARAM_INPUT, $data["CDOPERINCL"],    Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param("P_TREGIAO",     Param::PARAM_INPUT, $data["LOADALLREGION"], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param("P_CDFORNCARG",  Param::PARAM_INPUT, $data["CDFORNCARG"],    Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param("P_CDREGCARG",   Param::PARAM_INPUT, $data["CDREGCARG"],     Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param("P_IDERRO",      Param::PARAM_OUTPUT, NULL,                  Param::PARAM_TYPE_STR, 3));

      return $procedure->execute();
    } catch (\Exception $exception) {
      throw new \Exception("Erro ao executar procedure inc_forn_cota" . $exception->getMessage(), 500);
    }
  }

  public function deleteLogErrors(array $data): void {
    try {
      $this->connection->beginTransaction();

      $query = "DELETE FROM LOGERROCOTA
                WHERE CDFILIAL = :P_CDFILIAL
                      AND NRCOLEPRECO = :P_NRCOLEPRECO";

      $params = [
        "P_CDFILIAL"    => $data["CDFILIAL"],
        "P_NRCOLEPRECO" => $data["NRCOLEPRECO"]
      ];

      $this->util->crud($query, $params);

      $this->connection->commit();
    } catch (\Exception $exception) {
      $this->connection->rollback();

      throw new \Exception("Erro ao deletar logs de error: " . $exception->getMessage());
    }
  }
}