<?php

namespace SupNext\Services\QuoteSheetGrid;

use SupNext\Util\Util;

class UpdateProductService {
    private $util;

    public function __construct(Util $util) {
        $this->util = $util;
    }

    public function insertJustification($data) {
        try {
            $query = "INSERT INTO MOVOPITEMCOT
                      (
                        CDFILIALMCOT,
                        NRCOLEPRECOMCOT,
                        CDMARCAMCOT,
                        CDREGIAOMCOT,
                        CDFORNECEDMCOT,
                        CDPRODUTOMCOT,
                        DTOPERAITMCOT,
                        CDOPERADORMCOT,
                        DSALTERITMCOT,
                        DSJUSTITMCOT,
                        DSRDMUSUMCOT,
                        DSENDUSUMCOT,
                        DSNMUSUMCOT,
                        DSMETUSUMCOT,
                        NRORG
                    )
                    VALUES
                    (
                        :P_CDFILIALMCOT,
                        :P_NRCOLEPRECOMCOT,
                        :P_CDMARCAMCOT,
                        :P_CDREGIAOMCOT,
                        :P_CDFORNECEDMCOT,
                        :P_CDPRODUTOMCOT,
                        SYSDATE,
                        :P_CDOPERADORMCOT,
                        :P_DSALTERITMCOT,
                        :P_DSJUSTITMCOT,
                        :P_DSRDMUSUMCOT,
                        :P_DSENDUSUMCOT,
                        :P_DSNMUSUMCOT,
                        :P_DSMETUSUMCOT,
                        :P_NRORG
                    )";

            $param = [
                "P_CDFILIALMCOT"     => $data["CDFILIAL"],
                "P_NRCOLEPRECOMCOT"  => $data["NRCOLEPRECO"],
                "P_CDFORNECEDMCOT"   => $data["CDFORNECED"],
                "P_CDPRODUTOMCOT"    => $data["CDPRODUTO"],
                "P_CDMARCAMCOT"      => $data["CDMARCA"],
                "P_CDREGIAOMCOT"     => $data["CDREGIAO"],
                "P_CDOPERADORMCOT"   => $data["CDOPERADOR"],
                "P_DSALTERITMCOT"    => $data["DSALTERITM"],
                "P_DSJUSTITMCOT"     => $data["DSJUSTITM"],
                "P_DSRDMUSUMCOT"     => null,
                "P_DSENDUSUMCOT"     => null,
                "P_DSNMUSUMCOT"      => null,
                "P_DSMETUSUMCOT"     => null,
                "P_NRORG"            => $data["NRORG"]
            ];

            $this->util->crud($query, $param);
        } catch (Exception $exception) {
            throw new \Exception("Erro ao inserir justificativa: " . $exception->getMessage(), 500);
        }
    }

    public function updRegSupIndex(array $data): void {
        try {
            $query = "UPDATE ITEMCOLE
                      SET VRPRECUNIITM = :P_VRPRECUNIITM,
                          VRINDICEITMCOL = :P_VRINDICEITMCOL,
                          IDITMCOTPREC = 'S',
                          IDATUREGIALT = :P_IDATUREG,
                          IDATUFORNALT = :P_IDATUFORN
                      WHERE CDFILIAL = :P_CDFILIAL
                            AND NRCOLEPRECO = :P_NRCOLEPRECO
                            AND CDREGIAO = :P_CDREGIAO
                            AND CDFORNECED = :P_CDFORNECED
                            AND CDPRODUTO = :P_CDPRODUTO
                            AND CDMARCA = LPAD(:P_CDMARCA, 5, '0')
                            AND NRORG = :P_NRORG
                            AND NOT EXISTS (SELECT CDFORNECED, CDREGIAO
                                            FROM REFOREG
                                            WHERE REFOREG.CDFORNECED = ITEMCOLE.CDFORNECED
                                                  AND REFOREG.CDREGIAO = ITEMCOLE.CDREGIAO)";

            $params = [
                "P_VRPRECUNIITM"    => $data["VRPRECUNIITM"],
                "P_VRINDICEITMCOL"  => $data["VRINDICEITMCOL"],
                "P_IDATUREG"        => $data["P_IDATUREG"],
                "P_IDATUFORN"       => $data["P_IDATUFORN"],
                "P_CDFILIAL"        => $data["CDFILIAL"],
                "P_NRCOLEPRECO"     => $data["NRCOLEPRECO"],
                "P_CDREGIAO"        => $data["CDREGIAO"],
                "P_CDFORNECED"      => $data["CDFORNECED"],
                "P_CDPRODUTO"       => $data["CDPRODUTO"],
                "P_CDMARCA"         => $data["CDMARCA"],
                "P_NRORG"           => $data["NRORG"]
            ];

            $this->util->crud($query, $params);
        } catch (Exception $exception) {
            throw new \Exception("Erro ao atualizar região: " . $exception->getMessage(), 500);
        }
    }

    public function updateRegSup(array $data): void {
        try {
            $query = "UPDATE ITEMCOLE
                      SET VRPRECUNIITM = :P_VRPRECUNIITM,
                          IDITMCOTPREC = 'S',
                          IDATUREGIALT = :P_IDATUREG,
                          IDATUFORNALT = :P_IDATUFORN
                      WHERE CDFILIAL = :P_CDFILIAL
                            AND NRCOLEPRECO = :P_NRCOLEPRECO
                            AND CDREGIAO = :P_CDREGIAO
                            AND CDFORNECED = :P_CDFORNECED
                            AND CDPRODUTO = :P_CDPRODUTO
                            AND CDMARCA = LPAD(:P_CDMARCA, 5, '0')
                            AND NRORG = :P_NRORG
                            AND NOT EXISTS (SELECT CDFORNECED, CDREGIAO
                                            FROM REFOREG
                                            WHERE REFOREG.CDFORNECED = ITEMCOLE.CDFORNECED
                                                  AND REFOREG.CDREGIAO = ITEMCOLE.CDREGIAO)";

            $params = [
                "P_VRPRECUNIITM" => $data["VRPRECUNIITM"],
                "P_IDATUREG"     => $data["IDATUREG"],
                "P_IDATUFORN"    => $data["IDATUFORN"],
                "P_CDFILIAL"     => $data["CDFILIAL"],
                "P_NRCOLEPRECO"  => $data["NRCOLEPRECO"],
                "P_CDREGIAO"     => $data["CDREGIAO"],
                "P_CDFORNECED"   => $data["CDFORNECED"],
                "P_CDPRODUTO"    => $data["CDPRODUTO"],
                "P_CDMARCA"      => $data["CDMARCA"],
                "P_NRORG"        => $data["NRORG"]
            ];

            $this->util->crud($query, $params);
        } catch (Exception $e) {
            throw new \Exception('RECORD_ERROR');
        }
    }

    public function updatePreEcZerado(array $data): void {
        try {
            $query = "UPDATE ITEMCOLE
                      SET VRPRECUNIITM = VRPRECUNIITM
                      WHERE CDFILIAL = :P_CDFILIAL
                            AND NRCOLEPRECO = :P_NRCOLEPRECO
                            AND NRORG = :P_NRORG AND VRPRECUNIITM > 0
                            AND VRPRECECOITM <= 0";

            $params = [
                "P_CDFILIAL"    => $data["CDFILIAL"],
                "P_NRCOLEPRECO" => $data["NRCOLEPRECO"],
                'P_NRORG'       => $data["NRORG"]
            ];

            $this->util->crud($query, $params);
        } catch (Exception $exception) {
            throw new \Exception("Erro ao atualizar preço unitário: " . $exception->getMessage(), 500);
        }
    }

    public function insertNotificationSupplyTek(array $data): void {
        try {
            $query = "INSERT INTO NOTIFICSUPPLY
                    (
                        NRNOTIFICSUPPLY,
                        CDFILIAL,
                        CDOPERADOR,
                        NMNOTIFICACAO,
                        DSTEXTNOTIFIC,
                        IDNOTIFICLIDO,
                        NRORG,
                        DTINCLUSAO,
                        IDATIVO,
                        VRPRECOUNIOLD,
                        VRPRECOUNINEW,
                        VRREAJUSTE,
                        NMMARCA,
                        NMPRODUTO,
                        NMOPERADOR,
                        DSJUSTIFIC
                    )
                    VALUES
                    (
                        :P_NRNOTIFICSUPPLY,
                        :P_CDFILIAL,
                        :P_CDOPERADOR,
                        :P_NMNOTIFICACAO,
                        :P_DSTEXTNOTIFIC,
                        'N',
                        :P_NRORG,
                        SYSDATE,
                        'S',
                        :P_VRPRECOUNIOLD,
                        :P_VRPRECOUNINEW,
                        :P_VRREAJUSTE,
                        :P_NMMARCA,
                        :P_NMPRODUTO,
                        :P_NMOPERADOR,
                        :P_DSJUSTIFIC
                    )";


            $param = [
                "P_NRNOTIFICSUPPLY" => $data["NRNOTIFICSUPPLY"],
                "P_CDFILIAL"        => $data["CDFILIALSUPPLYTEK"],
                "P_CDOPERADOR"      => $data["CDOPERADOR"],
                "P_NMNOTIFICACAO"   => $data["NMNOTIFICACAO"],
                "P_DSTEXTNOTIFIC"   => $data["DSTEXTNOTIFIC"],
                "P_VRPRECOUNIOLD"   => $data["VRPRECOUNIOLD"],
                "P_VRPRECOUNINEW"   => $data["VRPRECOUNINEW"],
                "P_VRREAJUSTE"      => $data["VRREAJUSTE"],
                "P_NMMARCA"         => $data["NMMARCA"],
                "P_NMPRODUTO"       => $data["NMPRODUTO"],
                "P_NMOPERADOR"      => $data["NMOPERADOR"],
                "P_DSJUSTIFIC"      => $data["DSJUSTIFIC"],
                "P_NRORG"           => $data["NRORG"]
            ];

            $this->util->crud($query, $param);
        } catch (Exception $exception) {
            throw new \Exception("Erro ao inserir notificação supply tek: " . $exception->getMessage(), 500);
        }
    }

    public function updateQuotationParams(array $data): void {
        try {
            $query = "UPDATE COLETAPR
                      SET IDTIPCOLREG = 'G'
                      WHERE CDFILIAL = :P_CDFILIAL
                            AND NRCOLEPRECO = :P_NRCOLEPRECO
                            AND NVL(IDTIPCOLREG, 'G') NOT IN ('E', 'W')";

            $params = [
                "P_CDFILIAL"    => $data["CDFILIAL"],
                "P_NRCOLEPRECO" => $data["NRCOLEPRECO"],
            ];

            $this->util->crud($query, $params);
        } catch (Exception $exception) {
            throw new \Exception("Erro ao atualizar parâmertros de cotação: " . $exception->getMessage(), 500);
        }
    }

    public function updateChangedBrand(array $data): void {
        try {
            $query = "UPDATE ITEMCOLE
                        SET CDMARCA = :P_NEW_MARCA,
                        DSOBSITMCOL = :P_NEW_OBS
                        WHERE CDFILIAL = :P_CDFILIAL
                            AND NRCOLEPRECO = :P_NRCOLEPRECO
                            AND CDREGIAO = :P_CDREGIAO
                            AND CDFORNECED = :P_CDFORNECED
                            AND CDPRODUTO = :P_CDPRODUTO
                            AND NRORG = :P_NRORG";

            $params = [
                "P_NEW_MARCA"   => $data["CDMARCA"],
                "P_CDFILIAL"    => $data["CDFILIAL"],
                "P_NRCOLEPRECO" => $data["NRCOLEPRECO"],
                "P_CDFORNECED"  => $data["CDFORNECED"],
                "P_CDREGIAO"    => $data["CDREGIAO"],
                "P_CDPRODUTO"   => $data["CDPRODUTO"],
                "P_NEW_OBS"     => $data["DSJUSTITM"],
                "P_NRORG"       => $data["NRORG"]
            ];

            $this->util->crud($query, $params);
        } catch (Exception $exception) {
            throw new \Exception("Erro ao atualizar marca alterada: " . $exception->getMessage(), 500);
        }
    }
}
