import {
  ModalService,
  Form,
  Select,
  LoadingService,
} from '@zeedhi/common';
import { Metadata, Http, dayjs } from '@zeedhi/core';
import { AppState } from '@/controllers/AppState';
import { Utilities } from '@/util/Utilities';

export class ChangeValidityController {
  private utilities!: Utilities;

  private appState: AppState;

  private idSisDos: string;

  constructor() {
    this.utilities = new Utilities();
    this.appState = AppState.getInstance();
  }

  public async createModal(): Promise<void> {
    await ModalService.createFromJson(
      '/modals/quoteSheetGrid/changeValidity',
      true,
    );
  }

  public destroyModal(): void {
    ModalService.getModal('changeValidity')?.destroy();
  }

  public openModal(): void {
    ModalService.getModal('changeValidity').show();
  }

  public closeModal(): void {
    ModalService.getModal('changeValidity').hide();
  }

  public filterQuoteField(): void {
    const form = Metadata.getInstance<Form>('changeValidityForm');
    const quoteSelect = Metadata.getInstance<Select>('changeValidityQuote');
    const formValues = form.value;

    quoteSelect.datasource.setFilter({
      P_CDFILIAL: localStorage.getItem('CDFILIAL'),
      P_CDCOMPRADOR: formValues.changeValidityBuyer?.CDCOMPRADOR ?? 'T',
      P_DTINIVALCOL: formValues.oldValidity[0] ?? null,
      P_DTFINVALCOL: formValues.oldValidity[1] ?? null,
      P_TDATAS: formValues.oldValidity[0] && formValues.oldValidity[1] ? null : 'T',
      P_CDFORNECED: formValues.changeValiditySupplier?.CDFORNECED ?? 'T',
      P_NRORG: localStorage.getItem('NRORG'),
    });
  }

  public async changeValidity(): Promise<void> {
    const form = Metadata.getInstance<Form>('changeValidityForm');

    if (!form.validate()) return;

    LoadingService.show();

    try {
      const formValues = form.value;

      if (this.appState.IDSISDOS === '3') {
        if (!this.isInCurrentYear(formValues.newValidity[0])
          && !this.isInCurrentYear(formValues.oldValidity[0])
          && !this.isInCurrentYear(formValues.oldValidity[1])
        ) {
          this.utilities.showWarningDialog('Somente serão permitidas datas do ano atual.');

          return;
        }
      }

      const parameters = {
        CDCOMPRADOR: formValues.changeValidityBuyer?.CDCOMPRADOR ?? 'T',
        CDFILCENTCMP: this.appState.CDFILIAL,
        CDFORNECED: formValues.changeValiditySupplier?.CDFORNECED ?? 'T',
        NRCOLEPRECO: formValues.changeValidityQuote?.NRCOLEPRECO ?? 'T',
        DTINIVALCOL: formValues.oldValidity[0],
        DTFINVALCOL: formValues.oldValidity[1],
        DTFINVALITM: formValues.newValidity[0],
        DTINIVALITM: formValues.newValidity[1],
        NRORG: this.appState.NRORG,
      };

      await Http.put('/changeValidity', { params: parameters });

      form.clearForm();
      this.closeModal();

      LoadingService.hide();

      this.utilities.showSuccessDialog('sup::SUCCESS');
    } catch (error) {
      LoadingService.hide();
      this.utilities.showErrorDialog('sup::ERROR');
    }
  }

  private isInCurrentYear(dateStr): boolean {
    const date = dayjs(dateStr, 'DD/MM/YYYY');
    const currentYear = dayjs().year();

    return date.year() === currentYear;
  }
}
