import { TekGrid } from '@zeedhi/teknisa-components-common';
import {
  ModalService, Button, Textarea, LoadingService,
} from '@zeedhi/common';
import { Metadata, Http, IEventParam } from '@zeedhi/core';
import { Utilities } from '@/util/Utilities';

export class ObservationController {
  private utilities!: Utilities;

  constructor() {
    this.utilities = new Utilities();
  }

  public async createModal(): Promise<void> {
    await ModalService.createFromJson(
      '/modals/quoteSheetGrid/observationModal',
      true,
    );
  }

  public destroyModal(): void {
    ModalService.getModal('observationModal')?.destroy();
  }

  public openModal({ row }: IEventParam<Button>): void {
    ModalService.getModal('observationModal').show();
    this.setObservation(row);
  }

  public closeModal(): void {
    ModalService.getModal('observationModal').hide();
  }

  private async setObservation(row: IEventParam<Button>): Promise<void> {
    LoadingService.show();

    try {
      const { data } = await Http.get('/getObservation', { params: row });
      const observation = Metadata.getInstance<Textarea>('observation');

      observation.value = data.dataset.observation.DSOBSITMCOL;

      LoadingService.hide();
    } catch (error) {
      LoadingService.hide();
      this.utilities.showErrorDialog('sup::ERROR');
    }
  }

  public enableSaveButton(): void {
    const saveButton = Metadata.getInstance<Button>('saveObservation');

    saveButton.disabled = false;
  }

  public async saveObservation(): Promise<void> {
    try {
      const product = Metadata.getInstance<TekGrid>('multipleLevelsProductsGrid');
      const observation = Metadata.getInstance<Textarea>('observation');
      const row = product.datasource.currentRow;
      const parameters = { ...row, DSOBSITMCOL: observation.value };

      await Http.put('/saveObservation', { params: parameters });

      this.utilities.showSuccessDialog('sup::SUCCESS');
      this.closeModal();
    } catch (error) {
      this.utilities.showErrorDialog('sup::ERROR');
    }
  }
}
