/* eslint-disable no-console */
import {
  FormatterParserProvider, Http, I18n, dayjs,
} from '@zeedhi/core';
import { DialogService } from '@zeedhi/common';

export class Utilities {
  public formatValue(type: string, value: any): any {
    let valueReturn = '';

    if (value !== undefined) {
      const formatterFn = FormatterParserProvider.getFormatter('ZdNumber');

      switch (type) {
        case 'float':
          if (
            (value || value === 0)
            && value < 10000000000000
            && value > -10000000000000
          ) {
            valueReturn = formatterFn(value);
          } else {
            valueReturn = '-';
          }
          break;
        case 'number':
          valueReturn = value || value === 0 ? value.toFixed(0) : '';
          break;
        case 'date':
          valueReturn = value.substring(0, 10);
          break;
        default:
          valueReturn = value;
      }
    } else {
      valueReturn = value;
    }
    return valueReturn;
  }

  public formatFilter(obj: any): any {
    const objReturn = Object.entries(obj).map(([name, value]) => ({
      name,
      operator: '=',
      value,
    }));

    return objReturn;
  }

  public lightenColor(color: string, percent: number): string {
    const hex = color.replace('#', '');

    let r = parseInt(hex.substring(0, 2), 16);
    let g = parseInt(hex.substring(2, 4), 16);
    let b = parseInt(hex.substring(4, 6), 16);

    r = Math.floor((255 - r) * (percent / 100) + r);
    g = Math.floor((255 - g) * (percent / 100) + g);
    b = Math.floor((255 - b) * (percent / 100) + b);

    const lightenHex = '#'.concat(
      (r * 0x10000 + g * 0x100 + b).toString(16).padStart(6, '0'),
    );

    return lightenHex;
  }

  public async getLocalVar() {
    try {
      const response = await Http.get('/getLocalVar');

      return response.data.dataset.data;
    } catch (error) {
      return error;
    }
  }

  public validateProduct(initProduct, endProduct): { isValid: boolean, message?: string } {
    if (initProduct > endProduct) {
      return { isValid: false, message: 'Produto inicial deve ser menor ou igual ao produto final.' };
    }

    return { isValid: true };
  }

  public addCaracterInRight(code: string): string {
    const pad = 'ZZZZZZZZZZZZZZZZZZZZ';

    return code + pad.substr(0, pad.length - code.length);
  }

  public get productMask(): string {
    return '#.#.#.##.###.##';
  }

  public getSupplierMask(value: string): string {
    if (value.length <= 11) return '###.###.###-##';

    return '##.###.###/####-##';
  }

  public getWeekNumber(myDate: string): number {
    const date = dayjs(myDate);
    const januaryFirst = dayjs(new Date(date.year(), 0, 1));
    const numberOfDays = date.diff(januaryFirst, 'day');
    const result = Math.ceil((date.day() + 1 + numberOfDays) / 7);

    return result;
  }

  public showSuccessDialog(message: string, title: string = 'Sucesso'): void {
    DialogService.show({
      name: 'success-dialog',
      type: 'success',
      title: I18n.translate(title),
      text: I18n.translate(message),
    });
  }

  public showInfoDialog(message: string, title: string = 'Informação'): void {
    DialogService.show({
      name: 'info-dialog',
      type: 'info',
      title: I18n.translate(title),
      text: I18n.translate(message),
    });
  }

  public showWarningDialog(message: string, title: string = 'Atenção'): void {
    DialogService.show({
      name: 'warning-dialog',
      type: 'warning',
      title: I18n.translate(title),
      text: I18n.translate(message),
    });
  }

  public showErrorDialog(message: string, title: string = 'Error'): void {
    DialogService.show({
      name: 'error-dialog',
      type: 'error',
      title: I18n.translate(title),
      text: I18n.translate(message),
    });
  }

  public async deleteSelectedRows(
    component: any,
    selectedRows: any,
    route: string,
  ): Promise<void> {
    try {
      await Http.delete(`${route}/delete`, { data: selectedRows });
      component.selectedRows = [];
      component.reload();
    } catch (error) {
      this.showErrorDialog(`Erro ao deletar cotação: ${error}`);
    }
  }

  public async updateRow(
    component: any,
    row: any,
    route: string,
  ): Promise<void> {
    try {
      await Http.post(route, row);
      component.cancelEditedRows();
      component.reload();
    } catch (error) {
      this.showErrorDialog(`Erro ao atualizar cotação: ${error}`);
    }
  }
}
